@@ -6,7 +6,7 @@ use warnings;
 our $VERSION;
 
 BEGIN {
-    $VERSION = '0.17';
+    $VERSION = '0.18';
 }
 
 =encoding utf-8
@@ -32,7 +32,8 @@ The following aggregator functions are exposed:
 
     # Resolves with a list of arrayrefs, one per promise.
     # Rejects with the results from the first rejected promise.
-    my $all_p = Promise::XS::all( $promise1, $promise2, .. );
+    # Non-promises will be passed through as resolve values.
+    my $all_p = Promise::XS::all( $promise1, $promise2, 'abc' .. );
 
     # Resolves/rejects with the results from the first
     # resolved or rejected promise.
@@ -147,7 +148,7 @@ C<$new> is rejected with the relevant value(s).
 
 =back
 
-=head1 B<EXPERIMENTAL:> ASYNC/AWAIT SUPPORT
+=head1 ASYNC/AWAIT SUPPORT
 
 This module is L<Promise::AsyncAwait>-compatible.
 Once you load that module you can do nifty stuff like:
@@ -170,6 +171,10 @@ Once you load that module you can do nifty stuff like:
         $one_plus_number = shift;
     } );
 
+B<NOTE:> As of this writing, DEBUGGING-enabled perls trigger assertion
+failures in L<Future::AsyncAwait> (which underlies L<Promise::AsyncAwait>).
+If you’re not sure what that means, you probably don’t need to worry. :)
+
 =head1 EVENT LOOPS
 
 By default this library uses no event loop. This is a generally usable
